CREATE SCHEMA Unfall

-- Historie:
--
-- 17.12.2000 - 1.001 (1.002)
-- Verlegung der oertlichen_Zuordnung in das Straennetz
--
-- Verlegung der verwaltungstechn_Zuordnung in die Administration
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Unfall (
   Unfall_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Angaben_zur_Unfallzeit
      INTEGER NOT NULL REFERENCES Angaben_zur_Unfallzeit,
   hat_Unfallnummer
      INTEGER REFERENCES Unfallnummer,
   hat_Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfallort,
   hat_Angaben_z_Unfalleinteilung
      INTEGER NOT NULL REFERENCES Angaben_zur_Unfalleinteilung
)

CREATE TABLE Unfall__hat_Angaben_zum_Unfall (
   Unfall
      INTEGER NOT NULL REFERENCES Unfall,
   Angaben_zum_Unfall
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfall
)

CREATE TABLE Unfall__hat_Freiziffern (
   Unfall
      INTEGER NOT NULL REFERENCES Unfall,
   Freiziffern
      INTEGER NOT NULL REFERENCES Freiziffern
)

CREATE TABLE Unfall__hat_Unfallumstaende (
   Unfall
      INTEGER NOT NULL REFERENCES Unfall,
   Unfallumstaende
      INTEGER NOT NULL REFERENCES Unfallumstaende
)

CREATE TABLE Angaben_zum_Unfall (
   Angaben_zum_Unfall_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anzahl_der_Beteiligten
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_der_Beteiligten >= 0 ) AND ( Anzahl_der_Beteiligten <= 99 ) ),
   Anzahl_der_Getoeteten
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_der_Getoeteten >= 0 ) AND ( Anzahl_der_Getoeteten <= 99 ) ),
   Anzahl_Schwerverletzte
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_Schwerverletzte >= 0 ) AND ( Anzahl_Schwerverletzte <= 99 ) ),
   Anzahl_Leichtverletzte
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_Leichtverletzte >= 0 ) AND ( Anzahl_Leichtverletzte <= 99 ) ),
   CHECK ( Anzahl_der_Beteiligten>=1 )
)

CREATE TABLE Angaben_zur_Unfallzeit (
   Angaben_zur_Unfallzeit_ID
      INTEGER NOT NULL PRIMARY KEY,
   Wochentag_Unfall
      INTEGER REFERENCES Allgemeine_Objekte.Wochentag,
   Datum_Unfall
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum_Unfall LIKE '__.__.____' ),
   Uhrzeit
      VARCHAR(12) NOT NULL, -- Uhrzeit
   CHECK ( ( Uhrzeit LIKE '__:__' ) OR ( Uhrzeit LIKE '__:__:__' ) OR ( Uhrzeit LIKE '__:__:__:___' ) )
)

CREATE TABLE Unfallnummer (
   Unfallnummer_ID
      INTEGER NOT NULL PRIMARY KEY,
   Satzmerkmale
      INTEGER NOT NULL,
   Paginier_Nummer
      INTEGER
)

CREATE TABLE Freiziffern (
   Freiziffern_ID
      INTEGER NOT NULL PRIMARY KEY,
   Ziffer_1
      INTEGER NOT NULL,
   Ziffer_2
      INTEGER NOT NULL
)

CREATE TABLE Angaben_zum_Unfallort (
   Angaben_zum_Unfallort_ID
      INTEGER NOT NULL PRIMARY KEY,
   Fahrtrichtung_WB
      VARCHAR(30) NOT NULL,
   Ortslage
      INTEGER NOT NULL REFERENCES Ortslage,
   hat_verwaltungstechn_Zuordnung
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_UO,
   hat_oertliche_Zuordnung
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_UO
)

CREATE TABLE Ang_z_Unfort__hat_Ang_z_einm_S (
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Angaben_zum_Unfallort,
   Angaben_zur_einmuend_Strasse
      INTEGER NOT NULL REFERENCES Angaben_zur_einmuend_Strasse
)

CREATE TABLE Angaben_zur_einmuend_Strasse (
   Angaben_zur_einmuend_Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klasse_Nr_1
      INTEGER NOT NULL,
   Klasse_Nr_2
      INTEGER NOT NULL,
   Schluessel
      INTEGER
)

CREATE TABLE Ortslage (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Ortslage VALUES (1,'innerorts')
INSERT INTO Ortslage VALUES (2,'auerorts')

CREATE TABLE Unfallumstaende (
   Unfallumstaende_ID
      INTEGER NOT NULL PRIMARY KEY,
   Strassenbefestigung
      INTEGER REFERENCES Strassenbefestigung,
   Geschwindigkeitsbegrenzung
      INTEGER, -- Stundenkilometer
   CHECK ( Geschwindigkeitsbegrenzung>=0 ),
   Lichtzeichenanlage
      INTEGER REFERENCES Lichtzeichenanlage,
   Lichtverhaeltnisse
      INTEGER REFERENCES Lichtverhaeltnisse,
   CHECK ( ( Geschwindigkeitsbegrenzung >= 5 ) AND ( Geschwindigkeitsbegrenzung <= 130 ) )
)

CREATE TABLE Unfumstaende__Witterverhaeltn (
   Unfallumstaende
      INTEGER NOT NULL REFERENCES Unfallumstaende,
   Witterungsverhaeltnisse
      INTEGER NOT NULL REFERENCES Witterungsverhaeltnisse
)

CREATE TABLE Unfumstaende__Strassenzustand (
   Unfallumstaende
      INTEGER NOT NULL REFERENCES Unfallumstaende,
   Strassenzustand
      INTEGER NOT NULL REFERENCES Strassenzustand
)

CREATE TABLE Unfumstaende__hat_Char_d_Unfst (
   Unfallumstaende
      INTEGER NOT NULL REFERENCES Unfallumstaende,
   Charakterist_der_Unfallstelle
      INTEGER NOT NULL REFERENCES Charakterist_der_Unfallstelle
)

CREATE TABLE Unfumstde__hat_Besond_d_Unfst (
   Unfallumstaende
      INTEGER NOT NULL REFERENCES Unfallumstaende,
   Besonderheiten_d_Unfallstelle
      INTEGER NOT NULL REFERENCES Besonderheiten_d_Unfallstelle
)

CREATE TABLE Witterungsverhaeltnisse (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Witterungsverhaeltnisse VALUES (7,'Regen')
INSERT INTO Witterungsverhaeltnisse VALUES (8,'Schneefall/Hagel')
INSERT INTO Witterungsverhaeltnisse VALUES (9,'Nebel/Dunst')
INSERT INTO Witterungsverhaeltnisse VALUES (0,'Sturm')

CREATE TABLE Strassenzustand (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenzustand VALUES (0,'trocken')
INSERT INTO Strassenzustand VALUES (1,'feucht')
INSERT INTO Strassenzustand VALUES (2,'Glatteis')
INSERT INTO Strassenzustand VALUES (3,'Schneegltte')
INSERT INTO Strassenzustand VALUES (4,'gestreut')
INSERT INTO Strassenzustand VALUES (5,'Schlpfrigkeit')
INSERT INTO Strassenzustand VALUES (6,'schadhafte Fahrbahn')
INSERT INTO Strassenzustand VALUES (7,'winterglatt')

CREATE TABLE Strassenbefestigung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenbefestigung VALUES (5,'Beton')
INSERT INTO Strassenbefestigung VALUES (6,'Schwarzdecke')
INSERT INTO Strassenbefestigung VALUES (7,'Pflaster')
INSERT INTO Strassenbefestigung VALUES (8,'sonstige befestigte Strae')
INSERT INTO Strassenbefestigung VALUES (9,'unbefestigte Strae')

CREATE TABLE Lichtzeichenanlage (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Lichtzeichenanlage VALUES (0,'keine LZA')
INSERT INTO Lichtzeichenanlage VALUES (1,'LZA vorhanden')

CREATE TABLE Lichtverhaeltnisse (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Lichtverhaeltnisse VALUES (0,'Tageslicht')
INSERT INTO Lichtverhaeltnisse VALUES (1,'Dmmerung')
INSERT INTO Lichtverhaeltnisse VALUES (2,'Dunkelheit')

CREATE TABLE Charakterist_der_Unfallstelle (
   Charakterist_der_Unfallstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   Charakteristik_1
      INTEGER NOT NULL REFERENCES Charakteristik_Unfst,
   Charakteristik_2
      INTEGER NOT NULL REFERENCES Charakteristik_Unfst,
   Charakteristik_3
      INTEGER NOT NULL REFERENCES Charakteristik_Unfst,
   CHECK ( Charakteristik_3>=3 ),
   CHECK ( Charakteristik_2>=2 )
)

CREATE TABLE Charakteristik_Unfst (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Charakteristik_Unfst VALUES (1,'Kreuzung')
INSERT INTO Charakteristik_Unfst VALUES (2,'Einmndung')
INSERT INTO Charakteristik_Unfst VALUES (3,'Ein-/Ausfahrt Grundstck')
INSERT INTO Charakteristik_Unfst VALUES (4,'Steigung/Geflle')
INSERT INTO Charakteristik_Unfst VALUES (5,'Kuppe')
INSERT INTO Charakteristik_Unfst VALUES (6,'Kurve')
INSERT INTO Charakteristik_Unfst VALUES (7,'frei')
INSERT INTO Charakteristik_Unfst VALUES (8,'Steigung')
INSERT INTO Charakteristik_Unfst VALUES (9,'Geflle')

CREATE TABLE Besonderheiten_d_Unfallstelle (
   Besonderheiten_d_Unfallstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   Besonderheit_1
      INTEGER NOT NULL REFERENCES Besonderheiten_Unfst,
   Besonderheit_2
      INTEGER NOT NULL REFERENCES Besonderheiten_Unfst,
   Besonderheit_3
      INTEGER NOT NULL REFERENCES Besonderheiten_Unfst,
   CHECK ( Besonderheit_3>=3 ),
   CHECK ( Besonderheit_2>=2 )
)

CREATE TABLE Besonderheiten_Unfst (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Besonderheiten_Unfst VALUES (1,'unbersichtlich')
INSERT INTO Besonderheiten_Unfst VALUES (2,'schiengleicher Wegbergang')
INSERT INTO Besonderheiten_Unfst VALUES (3,'Zebrastreifen')
INSERT INTO Besonderheiten_Unfst VALUES (4,'Fugngerfurt')
INSERT INTO Besonderheiten_Unfst VALUES (5,'Haltestelle')
INSERT INTO Besonderheiten_Unfst VALUES (6,'Arbeitsstelle')
INSERT INTO Besonderheiten_Unfst VALUES (7,'verkehrsberuhigter Bereich')
INSERT INTO Besonderheiten_Unfst VALUES (8,'Querungshilfe')
INSERT INTO Besonderheiten_Unfst VALUES (9,'Kreisverkehr')

CREATE TABLE Beteiligte (
   Beteiligte_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_der_Verkehrsbeteiligung
      INTEGER, -- Art_der_Verkehrsbeteiligung
   CHECK ( ( Art_der_Verkehrsbeteiligung >= 1 ) AND ( Art_der_Verkehrsbeteiligung <= 93 ) ),
   Alter_Beteiligter
      INTEGER,
   Geschlecht_Beteiligter
      INTEGER NOT NULL REFERENCES Geschlecht,
   Anzahl_Fahrzeugbenutzer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl_Fahrzeugbenutzer >= 0 ) AND ( Anzahl_Fahrzeugbenutzer <= 99 ) ),
   von_Unfall
      INTEGER REFERENCES Unfall
)

CREATE TABLE Beteiligte__Unfallursachen (
   Beteiligte
      INTEGER NOT NULL REFERENCES Beteiligte,
   Unfallursachen
      INTEGER NOT NULL,
   CHECK ( ( Unfallursache >= 1 ) AND ( Unfallursache <= 69 ) )
)

CREATE TABLE Beteil__hat_weitergeh_Angaben (
   Beteiligte
      INTEGER NOT NULL REFERENCES Beteiligte,
   weitergehende_Angaben
      INTEGER NOT NULL REFERENCES weitergehende_Angaben
)

CREATE TABLE Geschlecht (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Geschlecht VALUES (1,'w')
INSERT INTO Geschlecht VALUES (2,'m')

CREATE TABLE Mitfahrerangaben (
   Mitfahrerangaben_ID
      INTEGER NOT NULL PRIMARY KEY,
   getoetete_Mitfahrer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( getoetete_Mitfahrer >= 0 ) AND ( getoetete_Mitfahrer <= 99 ) ),
   schwerverletzte_Mitfahrer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( schwerverletzte_Mitfahrer >= 0 ) AND ( schwerverletzte_Mitfahrer <= 99 ) ),
   leichtverletzte_Mitfahrer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( leichtverletzte_Mitfahrer >= 0 ) AND ( leichtverletzte_Mitfahrer <= 99 ) ),
   zu_Beteiligtem
      INTEGER REFERENCES Beteiligte
)

CREATE TABLE Mitfang__hat_Ang_z_Alt_u_Gesch (
   Mitfahrerangaben
      INTEGER NOT NULL REFERENCES Mitfahrerangaben,
   Angaben_z_Alter_und_Geschlecht
      INTEGER NOT NULL REFERENCES Angaben_z_Alter_und_Geschlecht
)

CREATE TABLE Angaben_z_Alter_und_Geschlecht (
   Angaben_z_Alter_und_Geschlecht_ID
      INTEGER NOT NULL PRIMARY KEY,
   Alter_Mitfahrer
      INTEGER NOT NULL,
   Geschlecht_Mitfahrer
      INTEGER NOT NULL REFERENCES Geschlecht
)

CREATE TABLE weitergehende_Angaben (
   weitergehende_Angaben_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kennzeichen
      INTEGER NOT NULL,
   Ortskenntnisse
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   Auslaenderkennung
      INTEGER NOT NULL,
   Art_der_Verletzung
      INTEGER NOT NULL REFERENCES Art_der_Verletzung,
   Angaben_zum_Fahrzeug
      INTEGER NOT NULL
)

CREATE TABLE Art_der_Verletzung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_der_Verletzung VALUES (1,'gettet')
INSERT INTO Art_der_Verletzung VALUES (2,'schwerverletzt')
INSERT INTO Art_der_Verletzung VALUES (3,'leichtverletzt')

CREATE TABLE Angaben_zur_Unfalleinteilung (
   Angaben_zur_Unfalleinteilung_ID
      INTEGER NOT NULL PRIMARY KEY,
   allgemeine_Unfallursache_1
      INTEGER NOT NULL, -- allgemeine_Unfallursache
   CHECK ( ( allgemeine_Unfallursache_1 >= 70 ) AND ( allgemeine_Unfallursache_1 <= 89 ) ),
   allgemeine_Unfallursache_2
      INTEGER, -- allgemeine_Unfallursache
   CHECK ( ( allgemeine_Unfallursache_2 >= 70 ) AND ( allgemeine_Unfallursache_2 <= 89 ) ),
   Unfalltyp
      INTEGER NOT NULL,
   Unfallart
      INTEGER NOT NULL,
   Unfallkategorie
      INTEGER NOT NULL,
   hat_Aufprall_auf_Hindernis
      INTEGER REFERENCES Aufprall_auf_Hindernis,
   CHECK ( ( Unfallkategorie >= 1 ) AND ( Unfallkategorie <= 9 ) ),
   CHECK ( ( Unfallart >= 0 ) AND ( Unfallart <= 9 ) ),
   CHECK ( ( Unfalltyp >= 100 ) AND ( Unfalltyp <= 799 ) ),
   CHECK ( allgemeine_Unfallursache_2>=71 )
)

CREATE TABLE Aufprall_auf_Hindernis (
   Aufprall_auf_Hindernis_ID
      INTEGER NOT NULL PRIMARY KEY,
   Hindernisart
      INTEGER NOT NULL REFERENCES Hindernisart,
   Fahrzustand
      INTEGER REFERENCES Fahrzustand
)

CREATE TABLE Hindernisart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Hindernisart VALUES (0,'Baum')
INSERT INTO Hindernisart VALUES (1,'Mast')
INSERT INTO Hindernisart VALUES (2,'Widerlager')
INSERT INTO Hindernisart VALUES (3,'Schutzplanke')
INSERT INTO Hindernisart VALUES (4,'sonstiges Hindernis')
INSERT INTO Hindernisart VALUES (5,'kein Aufprall')

CREATE TABLE Fahrzustand (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Fahrzustand VALUES (0,'Fahrzeug fahrbereit')
INSERT INTO Fahrzustand VALUES (1,'nicht fahrbereites Kfz')

CREATE TABLE verwaltungstechn_Zuordng_UO (
   verwaltungstechn_Zuordng_UO_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (verwaltungstechn_Zuordng_UO_ID) REFERENCES Administration.verwaltungstechn_Zuordnung
)

CREATE TABLE oertliche_Zuordnung_UO (
   oertliche_Zuordnung_UO_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_UO_ID) REFERENCES Strassennetz.oertliche_Zuordnung
)

